@@ -6,9 +6,12 @@ import warnings
 
 import astropy.units as u
 import numpy as np
+from astropy.utils import minversion
 
 __all__ = ['RegionMask']
 
+COPY_IF_NEEDED = False if not minversion(np, '2.0.0.dev') else None
+
 
 class RegionMask:
     """
@@ -40,12 +43,12 @@ class RegionMask:
         self.bbox = bbox
         self._mask = (self.data == 0)
 
-    def __array__(self, dtype=None, copy=None):
+    def __array__(self, dtype=None, copy=COPY_IF_NEEDED):
         """
         Array representation of the mask data array (e.g., for
         matplotlib).
         """
-        return np.asarray(self.data, dtype=dtype)
+        return np.array(self.data, dtype=dtype, copy=copy)
 
     @property
     def shape(self):
@@ -56,8 +59,8 @@ class RegionMask:
 
     def get_overlap_slices(self, shape):
         """
-        Get slices for the overlapping part of the region mask and a
-        2D array.
+        Get slices for the overlapping part of the region mask and a 2D
+        array.
 
         Parameters
         ----------
@@ -172,10 +175,7 @@ class RegionMask:
             return cutout
 
         # cutout is always a copy for partial overlap
-        if ~np.isfinite(fill_value):
-            dtype = float
-        else:
-            dtype = data.dtype
+        dtype = float if ~np.isfinite(fill_value) else data.dtype
         cutout = np.zeros(self.shape, dtype=dtype)
         cutout[:] = fill_value
         cutout[slices_small] = data[slices_large]
@@ -264,9 +264,8 @@ class RegionMask:
         multiple associated arrays (e.g., data and error arrays). It is
         used in this way by the `PixelAperture.do_photometry` method.
         """
-        if mask is not None:
-            if mask.shape != shape:
-                raise ValueError('mask and data must have the same shape')
+        if mask is not None and mask.shape != shape:
+            raise ValueError('mask and data must have the same shape')
 
         slc_large, slc_small = self.get_overlap_slices(shape)
         if slc_large is None:  # no overlap
